/*
 * Copyright (c) 2016 Razeware LLC
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

using UnityEngine;
using UnityEngine.Events;

namespace Completed
{
    /// <summary>
    /// Event to be used with an EventTrigger component to run another event (OnButtonHeld)
    /// while a UI button is being held down.
    /// </summary>
    public class HoldButtonEventHandler : MonoBehaviour
    {

        // The event to fire while the button is held
        public UnityEvent OnButtonHeld;

        // This is the state of our button (is it being pressed?)
        private bool pressed = false;

        // This method is called from an EventTrigger component 
        // when we press or release the button
        public void SetPressed(bool value)
        {
            pressed = value;
        }

        // If the button's state is pressed then we fire the
        // OnButtonHeld event.
        private void Update()
        {
            if (pressed)
                OnButtonHeld.Invoke();
        }

    }
}