/*
 * Copyright (c) 2016 Razeware LLC
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

using UnityEngine;
using UnityEngine.Events;
using UnityEngine.EventSystems;

/// <summary>
/// Handles event when the pointer is released.
/// OnPointerReleased can be assigned via the inspector.
/// </summary>
public class OnPointerUpEventHandler : MonoBehaviour, IPointerUpHandler, IPointerDownHandler
{

    // The event to fire when the pointer has been released.
    public UnityEvent OnPointerReleased;

    // Should this script be enabled on Awake?
    public bool enabledOnAwake = false;

    // Allows setting of the initial enabled state of this script. enabled == false will
    // prevent method events from firing.
    private void Awake()
    {
        enabled = enabledOnAwake;
    }

    public void OnPointerUp(PointerEventData eventData)
    {
        // If the script is not enabled then don't do anything!
        if (!enabled)
            return;

        // Otherwise fire the OnPointerReleased event.
        OnPointerReleased.Invoke();
    }

    // IPointerDownHandler implementation is required for IPointerUpHandler to work.
    // It does not have to actually do anything.
    public void OnPointerDown(PointerEventData eventData)
    {
    }
}