/*
 * Copyright (c) 2016 Razeware LLC
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

using UnityEngine;
using UnityEngine.Events;
using UnityEngine.EventSystems;

namespace Completed
{
    /// <summary>
    /// Handles events for dragging upward and downward.
    /// OnDragUpward and OnDragDownward can be assigned via the inspector.
    /// </summary>
    public class SwipeEventHandler : MonoBehaviour, IDragHandler
    {
        // Event to fire when the drag moves upward
        public UnityEvent OnDragUpward;
        // Event to fire when the drag moves downward
        public UnityEvent OnDragDownward;

        // Should this script be enabled on Awake?
        public bool enabledOnAwake = false;

        // Allows setting of the initial enabled state of this script. enabled == false will
        // prevent method events from firing.
        private void Awake()
        {
            enabled = enabledOnAwake;
        }

        public void OnDrag(PointerEventData eventData)
        {
            // If the script is not enabled then don't do anything!
            if (!enabled)
                return;

            // If the change in Y position of the pointer is positive
            // then the user is dragging upward. If it is negative
            // then the user is dragging downward.
            if (eventData.delta.y > 0)
                OnDragUpward.Invoke();
            else if (eventData.delta.y < 0)
                OnDragDownward.Invoke();
        }
    }
}