/*
 * Copyright (c) 2016 Razeware LLC
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

using UnityEngine;
using System.Collections;

/// <summary>
/// Responsible for 
/// - Creating new enemies via Spawn() running at spawnInterval
/// - Allowing access to destroy all enemies via ClearEnemies()
/// </summary>
public class EnemySpawner : MonoBehaviour
{
    // The number of seconds before spawning the next enemy.
    public float spawnInterval = 2;
    public GameObject enemyPrefab;

    // When this script is enabled start spawning enemies.
    private void OnEnable()
    {
        StartCoroutine(Spawn());
    }

    // This coroutine will spawn an enemy every spawnInterval.
    private IEnumerator Spawn()
    {
        WaitForSeconds delay = new WaitForSeconds(spawnInterval);
        while (true)
        {
            Instantiate(enemyPrefab, transform.position, Quaternion.identity);
            yield return delay;
        }
    }

    // This will be used to destroy all enemies on the screen when the game is over.
    public void ClearEnemies()
    {
        // Find all enemies active in the scene
        EnemyController[] enemies = FindObjectsOfType<EnemyController>();

        // Destory each one!
        for (int i = 0; i < enemies.Length; i++)
        {
            Destroy(enemies[i].gameObject);
        }
    }
}
