/*
 * Copyright (c) 2016 Razeware LLC
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

using UnityEngine;
using System.Collections.Generic;

/// <summary>
/// Responsible for slowing and restoring enemy movement speed when an
/// enemy enters an ice Patch Trigger area.
/// </summary>
public class IcePatchTrigger : MonoBehaviour
{
    // The enemies that entered the trigger
    private List<EnemyController> enemiesAffected = new List<EnemyController>();
    // When an enemy enters the trigger set its speed modifier to 1/4 to slow the enemy down.
    private void OnTriggerStay2D(Collider2D collision)
    {
        EnemyController enemyMovement = collision.GetComponent<EnemyController>();

        if (enemyMovement)
        {
            enemyMovement.SetSpeedModifier(0.25f);

            if (!enemiesAffected.Contains(enemyMovement))
                enemiesAffected.Add(enemyMovement);
        }
    }

    // When the enemy leaves the trigger set its speed modifier to 1 to restore normal speed.
    private void OnTriggerExit2D(Collider2D collision)
    {
        EnemyController enemyMovement = collision.GetComponent<EnemyController>();

        if (enemyMovement)
        {
            enemyMovement.SetSpeedModifier(1);
        }
    }

    // Ensure that enemy movement speed is restored if this ice patch
    private void OnDestroy()
    {
        for (int i = 0; i < enemiesAffected.Count; i++)
        {
            if (enemiesAffected[i] != null)
                enemiesAffected[i].SetSpeedModifier(1);
        }
    }
}
