/*
 * Copyright (c) 2016 Razeware LLC
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

using UnityEngine;

/// <summary>
/// Responsible for input via keyboard and mouse.
/// </summary>
public class StandaloneInputController : MonoBehaviour
{

    public WaterBalloonController waterBalloonPrefab;

    private PlayerController playerController;

    private void Start()
    {
        playerController = FindObjectOfType<PlayerController>();
    }

    private void Update()
    {
        // Rotate the cannon up with the up arrow.
        if (Input.GetKey(KeyCode.UpArrow))
            playerController.RotateCannon(1);

        // Rotate the cannon down with the down arrow
        if (Input.GetKey(KeyCode.DownArrow))
            playerController.RotateCannon(-1);

        // Fire a snowball when space is pressed
        if (Input.GetKeyDown(KeyCode.Space))
            playerController.Fire();

        // If the left mouse button is pressed then clone a waterballoon at the mouse pointer's location.
        if (waterBalloonPrefab)
        {
            if (Input.GetMouseButtonDown(0))
            {
                Vector2 worldPos = Camera.main.ScreenToWorldPoint(Input.mousePosition + Vector3.forward);
                WaterBalloonController waterBalloon = waterBalloonPrefab.MakeCopy(worldPos);

                waterBalloon.balloonRigidbody.isKinematic = false;
            }
        }
    }

    // Display some instructions so the player knows what buttons to press.
    private void OnGUI()
    {
        GUI.contentColor = Color.red;
        GUI.Label(new Rect(0, Screen.height - 60, Screen.width, 60),
            "Up/Down to aim\nSpace to Fire\nClick to drop ballon");
    }
}
